logging

package
v0.3.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 26, 2021 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetLogger

func GetLogger() *logrus.Logger

GetLogger returns the configured logger for use by the rest of the application.

func UpdateConfig

func UpdateConfig(logLevel string, logFormat string, logFile string) error

UpdateConfig overrides the default logging settings. This function is meant to be used during CLI initialization to update the logger based on config file and CLI args.

Types

This section is empty.

Jump to