Documentation
¶
Index ¶
- func CreateFile(filename string, directoryPerm, filePerm fs.FileMode) error
- func FileExists(path string) bool
- func FirstRunPrompt() error
- func OpenLink(link string) error
- func PromptBool(label string) (bool, error)
- func PromptFilePath(label, defaultValue string) (string, error)
- func PromptFilePathNoValidate(label, defaultValue string) (string, error)
- func PromptString(label string) (string, error)
- func WriteError(w http.ResponseWriter, message string, status int)
- type AwsArn
- type ErrorResponse
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CreateFile ¶ added in v0.2.19
CreateFile safely creates an empty file and any missing directory structure. The directories will have directoryPerm filemode. The file will have filePerm filemode.
func FileExists ¶
func FirstRunPrompt ¶ added in v0.1.15
func FirstRunPrompt() error
FirstRunPrompt gets user input to bootstrap a bare-minimum configuration.
func PromptBool ¶ added in v0.1.15
func PromptFilePath ¶ added in v0.1.15
func PromptFilePathNoValidate ¶ added in v0.1.15
func PromptString ¶ added in v0.1.15
func WriteError ¶ added in v0.1.16
func WriteError(w http.ResponseWriter, message string, status int)
WriteError writes a status code and plaintext error to the provided http.ResponseWriter. The error is written as plaintext so AWS SDKs will display it inline with an error message.
Types ¶
type AwsArn ¶
type ErrorResponse ¶ added in v0.1.16
Click to show internal directories.
Click to hide internal directories.